<template>
    <Head title="Categoria" />

    <AuthenticatedLayout>
        <div class="mb-4 inline-flex w-full overflow-hidden rounded-lg bg-white shadow-md">
            <div class="flex-none w-15 h-14">
              <div class="mx-3 px-8 py-3">
                 <PrimaryButton @click="openModal(1)">
                         CREAR
                    </PrimaryButton>
                </div>
            </div>
            <div class="grow h-14 py-2">
             
            </div>
            <div class="mx-3 px-8 py-3">
              <input type="text" class="shadow appearance-none border rounded  py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" v-model="searchTerm" placeholder="Buscar...">
                    <PrimaryButton   @click="search">
                         Buscar
                    </PrimaryButton>
            </div>
            <div class="mx-3 px-8 py-3">
                <div class="mx-2">
                    <span class="font-semibold text-blue-500">Inventario: Categoría</span>
                </div>
            </div>
        </div>
        <div class="inline-block min-w-full overflow-hidden rounded-lg shadow">
            <table class="table-auto border-collapse w-full">
                <thead>
                    <tr class="border-b bg-gray-50 text-left text-xs font-semibold uppercase tracking-wide text-gray-500">
                         <th class="px-2 py-1 bg-gray-800 text-gray-100 border">
                            N°
                        </th>
                        <th class="px-2 py-1 bg-gray-800 text-gray-100 border">
                            Nombre
                        </th>
                        <th class="py-1 px-3 bg-gray-800 text-gray-100 border">
                            Estado
                        </th>
                        <th class="px-2 py-1 bg-gray-800 text-gray-100 border">
                           Acción
                        </th>
                    </tr>
                </thead>
                <tbody>
                    <tr v-for="category in categories.data" :key="category.id" class="text-gray-700">
                        <td class=" px-2 py-1 border border-b border-gray-200 bg-white  text-sm">
                            <p class="text-gray-900 whitespace-no-wrap">{{ category.id }}</p>
                        </td>
                        <td class=" px-2 py-1 border border-b border-gray-200 bg-white text-sm">
                            <p class="text-gray-900 whitespace-no-wrap">{{ category.name }}</p>
                        </td>
                        <td class=" px-2 py-1 border border-b border-gray-200 bg-white  text-sm">
                            <div class="flex justify-center items-center">
                              
                                <h6  v-if="category.status=='activo'" class="bg-blue-500 text-white text-sm px-2 py-1 rounded">
                                    {{ category.status }}
                                </h6>
                                <h6  v-else="category.status=='inactivo'" class="bg-red-700 text-white text-sm px-2 py-1 rounded">
                                  {{ category.status }}
                                </h6>
                            </div>
                        </td>
                        <td class="border-b border-gray-200 bg-white px-3 py-0 text-sm">
                            <button class=" text-white font-bold py-1 px-1">
                             
                            <WarningButton 
                            @click="openModal(2,category.name,category.id)">
                                Editar
                            </WarningButton>
                      
                            </button> 
                            <DangerButton @click="eliminar(category.id,category.name)">
                               ELIMINAR
                            </DangerButton>
                        </td>
                    </tr>
                </tbody>
            </table>
            <div class="bg-white grid v-screen place-items-center">
                        <VueTailwindPagination
                            :current="categories.currentPage" 
                            :total="categories.total"
                            :per-page="categories.perPage"
                            @page-changed="onPageClick($event)"
                            text-before-input="Ir a página"
                            text-after-input="Adelante"
                        ></VueTailwindPagination>
                    </div>
            
        </div>
        <Modal :show="modal" @close="closeModal">
            <h2 class="p-3 text-lg font.medium text-hray-900">{{ title }}</h2>
            <div class="p-3 mt-6">
                <InputLabel for="name" value="Nombre:"></InputLabel>
                <TextInput id="name" ref="nameInput"
                v-model="form.name" type="text" class="mt-1 block w-3/4"
                placeholder="Nombre"></TextInput>
                <InputError :message="form.errors.name" class="mt-2"></InputError>
            </div>
            <div class="flex">
                <div class="flex-none px-5">
                  <PrimaryButton :disabled="form.processing" @click="save">
                    <i class="fa-solid fa-save"></i> Guardar
                </PrimaryButton>
                </div>
                <div class="grow h-14 ">
                  
                </div>
                <div class="flex-none px-5">
                  <DangerButton class="ml-3" :disabled="form.processing"
                @click="closeModal">
                    Cancelar
                </DangerButton>
                </div>
          </div>
            
        </Modal>
    </AuthenticatedLayout>
    <!-- modal categoria -->
    
       
</template>

<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import DangerButton from '@/Components/DangerButton.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import SelectInput from '@/Components/SelectInput.vue';
import WarningButton from '@/Components/WarningButton.vue';
import SecondaryButton from '@/Components/SecondaryButton.vue';
import Modal from '@/Components/Modal.vue';
import { Head,useForm } from '@inertiajs/vue3';
import { nextTick,ref } from 'vue';
import swal from 'sweetalert2';
import VueTailwindPagination from '@ocrv/vue-tailwind-pagination';
const nameInput = ref(null);
const modal = ref(false);
const title = ref('');
const operation = ref(1);
const id = ref('');
const props = defineProps({
    categories: Object,
  
})
const form = useForm({
    name:''
});
const formPage = useForm({});
const onPageClick = (event)=>{
    formPage.get(route('category.index',{page:event}));
}
const openModal = (op,name,caregoria) =>{
    modal.value = true;
    operation.value = op;
    id.value = caregoria;
    if(op == 1){
        title.value = 'Crear Categoria';
    }
    else{
        title.value = 'Editar Categoria';
        form.name=name;

    }
       
}
const save = () =>{
    if(operation.value == 1){
        form.post(route('category.store'),{
            onSuccess: () => {ok('Crear categoria')}
        });
    }
    else{
        form.put(route('category.update',id.value),{
            onSuccess: () => {ok('Actualizado')}
        });
    }
}
const ok = (msj) =>{
    form.reset();
    closeModal();
    swal.fire({title:msj,icon:'success'});
}
const closeModal = () =>{
    modal.value = false;
    form.reset();
}
const eliminar= (id,name) =>{
    const alerta = swal.mixin({
        buttonsStyling:true
    });
    alerta.fire({
        title:'Eliminar '+name+' ?',
        icon:'question', showCancelButton:true,
        confirmButtonText:'<i class="fa-solid fa-check"></i> Yes,delete',
        cancelButtonText:'<i class="fa-solid fa-ban"></i> Cancel'
    }).then((result) => {
        if(result.isConfirmed) {
            form.delete(route('category.destroy',id),{
                onSuccess: () =>{ok('Se elimino')}
            });
        }
    });
}
const searchTerm = ref('');
const search = async () => {
    try {
        form.name= searchTerm.value;
       
        form.get(route('search'),{
        });
       
    } catch (error) {
        console.error(error);
    }
};
</script>

